__package_name__ = 'django-tags-input'
__version__ = '4.2.0'
__author__ = 'Rick van Hattem'
__author_email__ = 'wolph@wol.ph'
__description__ = ' '.join('''
Django jQuery Tags Input is a Django field and widget wrapper that adds an easy
to use interface for `ManyToManyField` and `ForeignKey` fields in the forms of
autocompleting tags with optionally live creation of new linked
items
'''.strip().split())
__url__ = 'https://github.com/WoLpH/django-tags-input'
